==> crow-2.15.0.tar.bz2: crow-2.15.0/designer/util.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2009 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#ifndef CROWAPP_UTIL_H
#define CROWAPP_UTIL_H

#define CHECK(expr) ((expr) ? NoObj() : (CheckFailed(#expr, __FILE__, __LINE__), NoObj()))

namespace CrowApp {

struct NoObj { };

#ifdef _WIN32
	const int ModeDirPrivate  = 0;
#else
	const int ModeDirPrivate  = S_IRWXU|S_IRGRP|S_IXGRP;
#endif

typedef std::map<std::string, Glib::ustring> Settings;
typedef Glib::RefPtr<Gtk::RecentAction> PGtkRecentAction;
typedef std::list<std::string> StringList;

void CheckFailed(const char * expr, const char * file, int line);
void FatalError(const std::string & message);

template <class U, class V> U checked_cast(const V & v) {
	U u= (U)v;
	CHECK((V)u == v);
	return u;
}

template <class T> struct TSigned;
template <> struct TSigned<unsigned int> { typedef int Signed; };
template <> struct TSigned<unsigned long> { typedef long Signed; };
template <> struct TSigned<unsigned long long> { typedef long long Signed; };

template <class T> typename TSigned<T>::Signed SIGNED(T t) {
	return checked_cast<typename TSigned<T>::Signed>(t);
}

std::vector<std::string> Arguments(int argc, char ** argv);
StringList Split(const std::string & str, const char * dlm);

GHashTable * SettingsToHashTable(const Settings & settings);
Settings HashTableToSettings(GHashTable * table);

int GetKeyInt(const Settings & settings, const std::string & key);
void SetKeyInt(Settings * settings, const std::string & key, int value);

Glib::ustring GetKeyString(const Settings & settings, const std::string & key);
void SetKeyString(Settings * settings, const std::string & key, const char * const value);
void EnsureKeyString(Settings * settings, const std::string & key, const char * const value);

bool GetKeyBool(const Settings & settings, const std::string & key);
void SetKeyBool(Settings * settings, const std::string & key, bool value);

Gdk::Color GetKeyColor(const Settings & settings, const std::string & key);
void SetKeyColor(Settings * settings, const std::string & key, const Gdk::Color & value);

}

#endif

==> crow-2.17.1.tar.bz2: crow-2.17.1/designer/util.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2010 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#ifndef CROWAPP_UTIL_H
#define CROWAPP_UTIL_H

#define CHECK(expr) ((expr) ? NoObj() : (CheckFailed(#expr, __FILE__, __LINE__), NoObj()))

namespace CrowApp {

struct NoObj { };

#ifdef _WIN32
	const int ModeDirPrivate  = 0;
#else
	const int ModeDirPrivate  = S_IRWXU|S_IRGRP|S_IXGRP;
#endif

typedef const std::string & string_cr;
typedef const Glib::ustring & ustring_cr;

typedef std::map<std::string, Glib::ustring> Settings;
typedef Glib::RefPtr<Gtk::RecentAction> PGtkRecentAction;
typedef std::list<std::string> StringList;

void CheckFailed(const char * expr, const char * file, int line);
void FatalError(string_cr message);

template <class U, class V> U checked_cast(const V & v) {
	U u= (U)v;
	CHECK((V)u == v);
	return u;
}

template <class T> struct TSigned;
template <> struct TSigned<unsigned int> { typedef int Signed; };
template <> struct TSigned<unsigned long> { typedef long Signed; };
template <> struct TSigned<unsigned long long> { typedef long long Signed; };

template <class T> typename TSigned<T>::Signed SIGNED(T t) {
	return checked_cast<typename TSigned<T>::Signed>(t);
}

std::vector<std::string> Arguments(int argc, char ** argv);
StringList Split(string_cr str, const char * dlm);

GHashTable * SettingsToHashTable(const Settings & settings);
Settings HashTableToSettings(GHashTable * table);

int GetKeyInt(const Settings & settings, string_cr key);
void SetKeyInt(Settings * settings, string_cr key, int value);

Glib::ustring GetKeyString(const Settings & settings, string_cr key);
void SetKeyString(Settings * settings, string_cr key, const char * const value);
void EnsureKeyString(Settings * settings, string_cr key, const char * const value);

bool GetKeyBool(const Settings & settings, string_cr key);
void SetKeyBool(Settings * settings, string_cr key, bool value);

Gdk::Color GetKeyColor(const Settings & settings, string_cr key);
void SetKeyColor(Settings * settings, string_cr key, const Gdk::Color & value);

void UnhandledException();

}

#endif
